import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { IonicModule } from '@ionic/angular';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { CloudQuery, CloudObject, Pointer } from '../../lib/community_ncloud'; // 确保路径正确

interface Work {
  WorkId: string; // 修改为 WorkId
  title: string;
  description: string;
  fileUrl: string;
  avatarUrl: string;
  userName: string;
  updatedAt: string;
  likesCount: number;
  category: string;
  comments: string[];
}


interface Comment {
  CommentId: string;
  userId: string;
  userName: string;
  avatarUrl: string;
  description: string;
  updatedAt: string;
  likesCount: number;
}

@Component({
  selector: 'app-art-detail',
  templateUrl: './art-detail.component.html',
  styleUrls: ['./art-detail.component.scss'],
  standalone: true,
  imports: [IonicModule, CommonModule, FormsModule]
})
export class ArtDetailComponent implements OnInit {
  artwork?: Work;
  comments: Comment[] = [];
  isLiked = false;
  isSaved = false;
  commentText = '';

  constructor(
    private route: ActivatedRoute,
    private router: Router
  ) {
    const navigation = this.router.getCurrentNavigation();
    if (navigation?.extras.state) {
      this.artwork = navigation.extras.state['artwork'] as Work;
    }
  }

  ngOnInit() {
    if (this.artwork) {
      this.loadComments();
    }
  }

  // 加载评论数据
  async loadComments() {
    try {
      // 使用 map() 生成每个评论ID的查询，并通过 Promise.all 并行执行这些查询
      const commentQueries = this.artwork?.comments.map(commentId => {
        const query = new CloudQuery('Comment');
        query.equalTo('CommentId', commentId); // 查询对应 CommentId 的评论
        return query.find();
      });

      if (commentQueries) {
        const results = await Promise.all(commentQueries); // 等待所有评论查询结果
        // 将查询结果转换为 Comment 对象并更新 comments 数组
        this.comments = results.flat().map((commentObj: CloudObject) => {
          const data = commentObj.data as Comment;
          return {
            CommentId: data.CommentId,
            userId: data.userId,
            userName: data.userName,
            avatarUrl: data.avatarUrl,
            description: data.description,
            updatedAt: data.updatedAt,
            likesCount: data.likesCount
          };
        });
      }
    } catch (error) {
      console.error('加载评论数据失败:', error);
    }
  }

  toggleLike() {
    this.isLiked = !this.isLiked;
    if (this.artwork) {
      this.artwork.likesCount += this.isLiked ? 1 : -1;
    }
  }

  toggleSave() {
    this.isSaved = !this.isSaved;
    this.showToast(this.isSaved ? '已收藏' : '已取消收藏');
  }

  async submitComment() {
    if (!this.commentText.trim()) {
      this.showToast('请输入评论内容');
      return;
    }
    // 这里添加提交评论的逻辑
    this.showToast('评论已提交');
    this.commentText = '';
  }

  private async showToast(message: string) {
    const toast = document.createElement('ion-toast');
    toast.message = message;
    toast.duration = 2000;
    toast.position = 'top';
    document.body.appendChild(toast);
    await toast.present();
  }

  goBack() {
    this.router.navigate(['/tabs/tab3']);
  }
  async shareArtwork() {
    if (navigator.share) {
      try {
        await navigator.share({
          title: this.artwork?.title,
          text: this.artwork?.description,
          url: window.location.href
        });
      } catch (error) {
        this.showToast('分享失败，请重试');
      }
    } else {
      await navigator.clipboard.writeText(window.location.href);
      this.showToast('链接已复制到剪贴板');
    }
  }

  trackByCommentId(index: number, comment: Comment) {
    return comment.CommentId;
  }

}
/*
export class ArtDetailComponent implements OnInit {
  artwork?: Artwork;
  isLiked = false;
  isSaved = false;
  commentText = '';

  constructor(
    private route: ActivatedRoute,
    private router: Router
  ) {
    const navigation = this.router.getCurrentNavigation();
    if (navigation?.extras.state) {
      this.artwork = navigation.extras.state['artwork'] as Artwork;
      // 添加示例评论
      this.artwork.comments = [
        {
          id: '1',
          userId: 'user1',
          userName: '艺术评论家',
          avatarUrl: 'assets/img/lunbo2.png',
          content: '这幅作品的构图和用色都非常出色，展现了艺术家深厚的功底。',
          date: '2024-01-15',
          likes: 23
        },
        {
          id: '2',
          userId: 'user2',
          userName: '美术爱好者',
          avatarUrl: 'assets/img/lunbo3.png',
          content: '光影处理很到位，整体氛围感很强。',
          date: '2024-01-14',
          likes: 15
        }
      ];
    }
  }

  ngOnInit() {
    if (!this.artwork) {
      const artId = this.route.snapshot.paramMap.get('id');
      console.log('Art ID:', artId);
    }
  }

  toggleLike() {
    this.isLiked = !this.isLiked;
    if (this.artwork) {
      this.artwork.likesCount += this.isLiked ? 1 : -1;
    }
  }

  toggleSave() {
    this.isSaved = !this.isSaved;
    this.showToast(this.isSaved ? '已收藏' : '已取消收藏');
  }

  async shareArtwork() {
    if (navigator.share) {
      try {
        await navigator.share({
          title: this.artwork?.title,
          text: this.artwork?.description,
          url: window.location.href
        });
      } catch (error) {
        this.showToast('分享失败，请重试');
      }
    } else {
      await navigator.clipboard.writeText(window.location.href);
      this.showToast('链接已复制到剪贴板');
    }
  }

  async submitComment() {
    if (!this.commentText.trim()) {
      this.showToast('请输入评论内容');
      return;
    }
    // 这里添加提交评论的逻辑
    this.showToast('评论已提交');
    this.commentText = '';
  }

  private async showToast(message: string) {
    const toast = document.createElement('ion-toast');
    toast.message = message;
    toast.duration = 2000;
    toast.position = 'top';
    document.body.appendChild(toast);
    await toast.present();
  }

  goBack() {
    this.router.navigate(['/tabs/tab3']);
  }
}
*/